// synthv1_param.h
//
/****************************************************************************
   Copyright (C) 2012-2014, rncbc aka Rui Nuno Capela. All rights reserved.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

*****************************************************************************/

#ifndef __synthv1_param_h
#define __synthv1_param_h

#include "synthv1.h"


//-------------------------------------------------------------------------
// synthv1_param - decl.
//

namespace synthv1_param
{
	// Default parameter name/value helpers.
	const char *paramName(synthv1::ParamIndex index);
	float paramDefaultValue(synthv1::ParamIndex index);
};


#endif	// __synthv1_param_h

// end of synthv1_param.h
